import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог выбора из двух вариантов
 */
ModalView {
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer(true)
        onCancel: handler.sendAnswer(false)
    }

    implicitWidth: image.visible ? Math.max(defaultWidth, image.width + leftPadding + rightPadding) : defaultWidth

    contentItem: ColumnLayout {
        spacing: 24
        ColumnLayout {
            spacing: 16
            Image {
                id: image
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredHeight: 72
                source: Style.parameter(params.image)
            }

            BasicLabel {
                Layout.fillWidth: true
                Style.class: "choiceBoxMessage"
                horizontalAlignment: Text.AlignHCenter
                Tr { tr: params.message }
            }

            BasicLabel {
                Layout.fillWidth: true
                Style.class: "choiceBoxNote"
                horizontalAlignment: Text.AlignHCenter
                visible: text.length > 0
                Tr { tr: params.note }
            }
        }

        RowLayout {
            spacing: 16
            BasicButton {
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: "choiceBoxYes"
                Tr { tr: params.yesButton }
                onClicked: handler.sendAnswer(true)
            }
            BasicButton {
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: "choiceBoxNo"
                Tr { tr: params.noButton }
                onClicked: handler.sendAnswer(false)
            }
        }
    }

    DialogHandler { id: handler }
}
